==> centreon-web-23.04.26.tar.gz: centreon-web-23.04.26/src/Core/Severity/RealTime/Infrastructure/API/FindSeverity/FindSeverityPresenter.php <==
<?php

/*
 * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Severity\RealTime\Infrastructure\API\FindSeverity;

use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
use Core\Severity\RealTime\Application\UseCase\FindSeverity\FindSeverityPresenterInterface;
use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;

class FindSeverityPresenter extends AbstractPresenter implements FindSeverityPresenterInterface
{
    /**
     * @param RequestParametersInterface $requestParameters
     * @param PresenterFormatterInterface $presenterFormatter
     */
    public function __construct(
        private RequestParametersInterface $requestParameters,
        protected PresenterFormatterInterface $presenterFormatter,
    ) {
    }

    /**
     * @param mixed $data
     */
    public function present(mixed $data): void
    {
        parent::present([
            'result' => $data->severities,
            'meta' => $this->requestParameters->toArray()
        ]);
    }
}

==> centreon-web-24.04.20.tar.gz: centreon-web-24.04.20/src/Core/Severity/RealTime/Infrastructure/API/FindSeverity/FindSeverityPresenter.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Severity\RealTime\Infrastructure\API\FindSeverity;

use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
use Core\Severity\RealTime\Application\UseCase\FindSeverity\FindSeverityPresenterInterface;

class FindSeverityPresenter extends AbstractPresenter implements FindSeverityPresenterInterface
{
    /**
     * @param RequestParametersInterface $requestParameters
     * @param PresenterFormatterInterface $presenterFormatter
     */
    public function __construct(
        private RequestParametersInterface $requestParameters,
        protected PresenterFormatterInterface $presenterFormatter,
    ) {
    }

    /**
     * @param mixed $data
     */
    public function present(mixed $data): void
    {
        parent::present([
            'result' => $data->severities,
            'meta' => $this->requestParameters->toArray(),
        ]);
    }
}
